@@ -19,16 +19,15 @@
     02110-1301, USA.
 */
 
-#include "displaynameeditwidget.h"
 #include "nameeditdialog.h"
-
-#include <QFormLayout>
+#include "displaynameeditwidget.h"
 
 #include <KComboBox>
 #include <KLineEdit>
 #include <KLocalizedString>
 
 #include <QDialogButtonBox>
+#include <QFormLayout>
 #include <QPushButton>
 
 NameEditDialog::NameEditDialog(QWidget *parent)
@@ -90,7 +89,7 @@ NameEditDialog::NameEditDialog(QWidget *parent)
     mSuffixCombo->addItems(suffixList);
 
     mPrefixCombo->lineEdit()->setFocus();
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
